@@ -1,10 +1,11 @@
 `plot.logistic.fit.fnc` <-
-function(x, data, method = "cut", where = seq(0, 1, by=0.1), ...) {
+function(x, data, method = "cut", where = seq(0, 1, by=0.1), scalesize=NA, ...) {
   require(lme4, quietly = TRUE)
   require(Design, quietly = TRUE)
-  if (class(x)[1]=="glmer") {
-    depvar = as.character(formula(attr(x@frame, "terms")))[2]
-    probs = 1/(1+exp(-fitted(x)))
+  if (class(x)[1]=="mer") {
+    y=attr(x@frame, "terms")
+    depvar = names(attr(terms(y),"dataClasses")[attr(terms(y),"response")])
+    probs = fitted(x)   # this used to be the fitted logit, but is now the fitted probability
   } else {
     if (class(x)[1] == "lrm") {
       depvar = as.character(formula(x$call))[2]
@@ -15,6 +16,7 @@ function(x, data, method = "cut", where = seq(0, 1, by=0.1), ...) {
   }
   if (method == "cut") {
     classes = cut2(probs, where, levels.mean = TRUE)
+    classCounts = table(classes)
     means = tapply(as.numeric(data[,depvar])-1, classes, mean)
   } else {
     if (method == "shingle") {
@@ -32,7 +34,13 @@ function(x, data, method = "cut", where = seq(0, 1, by=0.1), ...) {
      xlab = "mean predicted probabilities", 
      ylab = "observed proportions", type="n")
   abline(0, 1, col = "grey")
-  points(as.numeric(names(means)), means)
+  if ((method=="cut") & (!is.na(scalesize))) {
+    symbols(as.numeric(names(means)),as.numeric(means), circles=as.numeric(classCounts), 
+     inches=scalesize, main=" ", add=T)
+  } else {
+    points(as.numeric(names(means)), means)
+  }
+
   mtext(paste("R-squared: ", round(cor(as.numeric(names(means)), means)^2,2),
   sep=""), 3, 1.5)
 }
